%% LDA: Calculate the LDA plane normal that best separates the the 2 classes of coordinates
% 
% Arguments:
% 	class1_coord: Coordinates of atoms in class 1. Type: 3xN double
% 	class2_coord: Coordinates of atoms in class 2. Type: 3xN double
% 
% Returns:
% 	plane_norm: LDA plane normal that bests separates the 2 classes of coordinates. Type: 3x1 double
function [plane_norm] = LDA(class1_coord, class2_coord)
	class1_mean = mean(class1_coord, 2);
	class2_mean = mean(class2_coord, 2);

	class1_delta = (class1_coord - class1_mean*ones(1,size(class1_coord,2)));
	class2_delta = (class2_coord - class2_mean*ones(1,size(class2_coord,2)));

	S_1 = class1_delta * class1_delta';
	S_2 = class2_delta * class2_delta';

	S_w_inv = inv(S_1 + S_2);

	plane_norm = S_w_inv * (class1_mean - class2_mean);
	plane_norm = plane_norm/norm(plane_norm);
end