%% calc_GNM: Calculate the GNM modes given the C-alpha coordinates of a protein
% 
% Arguments:
% 	coord: Coordinates of the C-alpha atoms. Type: 3xN double
% 
% Returns: 
% 	eigvecs: Eigenvectors of the GNM modes ordered in descending order of the respective eigenvalues. Type: NxN double
% 	eigvals: Eigenvalues of the GNM modes ordered in descending order. Type: N double
function [eigvecs, eigvals] = calc_GNM(coord)
    % Calculate the Hessian inverse
    contact_matrix = get_Hess_inv(coord, 10);

    % Eigenvalue decomposition
    [eigvecs, eigvals, ~] = svd(contact_matrix);
    eigvals = diag(eigvals);

    % Should only have one zero eigenvalue
    assert(length(find(eigvals < 10^-6)) < 2, 'Error: More than one zero Eigvalues');
end