%% calc_IDD: Find the IDD plane and mean transition mid point
% 
% Arguments:
% 	prot_prot_pdb_struct_obj: Protein PDB structure object obtained from running readpdb. Type: 1xN struct
% 
% Returns:
% 	IDD_norm: Vector that is orthonormal to the IDD plane. Type: 3x1 double
% 	mean_mid_point_transitions: Mean of the mid-point of the transition points. Type: 3x1 double
% 	num_transition_points: Number of transition points. Type: int32
function [IDD_norm, mean_mid_point_transitions, num_transition_points] = calc_IDD(prot_pdb_struct_obj)
	ca_pdb_struct_obj = getAtomByAtomName(prot_pdb_struct_obj, 'CA');
	CA_no = size(ca_pdb_struct_obj, 2);
	CA_coord = [ca_pdb_struct_obj.coord];

	[eigvecs, eigvals] = calc_GNM(CA_coord);

	% Take the eigenvector of the slowest mode
	slowest_eigvec = eigvecs(:,end-1);

	% Assign true to pos_eigvec_elem when element of eigenvector is positive
	pos_eigvec_elem = false(CA_no,1);
	pos_eigvec_elem(slowest_eigvec > 0) = true;
	ca_pdb_struct_obj = setAttribute(ca_pdb_struct_obj, 1:length(ca_pdb_struct_obj), 'eigvec_elem', pos_eigvec_elem);

	[IDD_norm, mean_mid_point_transitions, num_transition_points] = calc_IDD_plane(ca_pdb_struct_obj);
end









