%% GNM_Hess_inv: Calculate GNM's Hessian inverse using a protein's C-alpha atoms
% 
% Arguments:
% 	coord: C-alpha atom coordinates. Type: 3xN double
% 
% Optional Arguments:
% 	cutoff: Cutoff used to define contacts between atoms. Same unit as the coords. Type: double. Default: 10
% 
% Returns:
% 	Hess_inv: GNM's Hessian inverse matrix. Type: NxN double
function [Hess_inv] = get_Hess_inv(coord, cutoff)

	if ~exist('cutoff', 'var')
		cutoff = 10;
	end

	atom_no = size(coord, 2);
	Hess_inv = zeros(atom_no, atom_no);

	for atom_idx_1 = 1:atom_no
		
		for atom_idx_2 = (atom_idx_1+1):atom_no
			dist = sqrt(sum((coord(:,atom_idx_1) - coord(:,atom_idx_2)) .^ 2));

			if (dist <= cutoff)
				Hess_inv(atom_idx_1,atom_idx_2) = -1;
				Hess_inv(atom_idx_2,atom_idx_1) = -1;
				Hess_inv(atom_idx_1,atom_idx_1) = Hess_inv(atom_idx_1,atom_idx_1) + 1;
				Hess_inv(atom_idx_2,atom_idx_2) = Hess_inv(atom_idx_2,atom_idx_2) + 1;
			end
		end
	end
end